==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-galego.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pxina anterior");
define("_NEXT","Pxina seguinte");
define("_SEARCHRESULTS","Resultados da Bsqueda");
define("_PAGE","pxina(s) ");
define("_RETURNTO","Voltar a");
define("_DEACTIVATE","Desactivar");
define("_ACTIVATE","Activar");
define("_ENCYCLOPEDIA","Enciclopedia");
define("_NOCONTENTFORLETTER","Desculpe, non existe contido pola letra");
define("_ENCYSELECTLETTER","Seleccione unha letra da seguinte lista para consultar termos:");
define("_COPYRIGHT","Copyright &copy; por $sitename. Tdo-los Dereitos Reservados.");
define("_YOURADMINENCY"," Administrador, esta enciclopedia non est activa!");
define("_ENCYNOTACTIVE","Desculpe, esta enciclopedia non est activa neste momento.");
define("_AVAILABLEENCYLIST","Lista de Enciclopedias dispoibles en");
define("_YOURADMININACTIVELIST"," Administrador: Lista de Enciclopedias Inactivas:");
define("_NORESULTSTEXT","Non hai Resultados no Texto dos Termos...");
define("_NORESULTSTITLE","Non hai Resultados no Ttulos dos Termos...");
define("_SEARCHRESULTSFOR","Resultados da Bsqueda de:");
define("_SEARCHNOTCOMPLETE","As Opcins de Bsqueda non estn completas. Intnteo de novo.");
define("_RESULTSINTERMTITLE","Resultados nos ttulos dos termos:");
define("_RESULTSINTERMTEXT","Resultados no texto dos termos:");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-galego.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pxina anterior");
define("_NEXT","Pxina seguinte");
define("_SEARCHRESULTS","Resultados da Bsqueda");
define("_PAGE","pxina(s) ");
define("_RETURNTO","Voltar a");
define("_DEACTIVATE","Desactivar");
define("_ACTIVATE","Activar");
define("_ENCYCLOPEDIA","Enciclopedia");
define("_NOCONTENTFORLETTER","Desculpe, non existe contido pola letra");
define("_ENCYSELECTLETTER","Seleccione unha letra da seguinte lista para consultar termos:");
define("_COPYRIGHT","Copyright &copy; por $sitename. Tdo-los Dereitos Reservados.");
define("_YOURADMINENCY"," Administrador, esta enciclopedia non est activa!");
define("_ENCYNOTACTIVE","Desculpe, esta enciclopedia non est activa neste momento.");
define("_AVAILABLEENCYLIST","Lista de Enciclopedias dispoibles en");
define("_YOURADMININACTIVELIST"," Administrador: Lista de Enciclopedias Inactivas:");
define("_NORESULTSTEXT","Non hai Resultados no Texto dos Termos...");
define("_NORESULTSTITLE","Non hai Resultados no Ttulos dos Termos...");
define("_SEARCHRESULTSFOR","Resultados da Bsqueda de:");
define("_SEARCHNOTCOMPLETE","As Opcins de Bsqueda non estn completas. Intnteo de novo.");
define("_RESULTSINTERMTITLE","Resultados nos ttulos dos termos:");
define("_RESULTSINTERMTEXT","Resultados no texto dos termos:");

?>
